==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebCardMediaDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardMediaDescription } from "./WebCardMediaDescription";
/**
 * @hidden
 */
export let WebCardMediaDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCardMediaDescriptionMetadata extends Base {
        static b(a) {
            if (WebCardMediaDescriptionMetadata.a == null) {
                WebCardMediaDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCardMediaDescriptionMetadata.c(WebCardMediaDescriptionMetadata.a);
            }
            if (a.k(WebCardMediaDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCardMediaDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CardMedia");
            a.item("__tagNameWC", "String:igc-card-media");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebCardMediaDescriptionMetadata.b(a);
            a.ac("WebCardMedia", () => new WebCardMediaDescription());
            a.ab("WebCardMedia", WebCardMediaDescriptionMetadata.a);
        }
    }
    WebCardMediaDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCardMediaDescriptionMetadata, 'WebCardMediaDescriptionMetadata');
    WebCardMediaDescriptionMetadata.a = null;
    return WebCardMediaDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebCardMediaDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardMediaDescription } from "./WebCardMediaDescription";
/**
 * @hidden
 */
export let WebCardMediaDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCardMediaDescriptionMetadata extends Base {
        static b(a) {
            if (WebCardMediaDescriptionMetadata.a == null) {
                WebCardMediaDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCardMediaDescriptionMetadata.c(WebCardMediaDescriptionMetadata.a);
            }
            if (a.k(WebCardMediaDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCardMediaDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CardMedia");
            a.item("__tagNameWC", "String:igc-card-media");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebCardMediaDescriptionMetadata.b(a);
            a.ae("WebCardMedia", () => new WebCardMediaDescription());
            a.ad("WebCardMedia", WebCardMediaDescriptionMetadata.a);
        }
    }
    WebCardMediaDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCardMediaDescriptionMetadata, 'WebCardMediaDescriptionMetadata');
    WebCardMediaDescriptionMetadata.a = null;
    return WebCardMediaDescriptionMetadata;
})();
